#if [ -r etc/rc.d/rc.font ]; then
#  rm -f etc/rc.d/rc.font.new
#else
#  mv etc/rc.d/rc.font.new etc/rc.d/rc.font
#fi
( cd usr/share/kbd/keymaps ; rm -rf ppc )
( cd usr/share/kbd/keymaps ; ln -sf mac ppc )
( cd usr/bin ; rm -rf psfaddtable )
( cd usr/bin ; ln -sf psfxtable psfaddtable )
( cd usr/bin ; rm -rf psfgettable )
( cd usr/bin ; ln -sf psfxtable psfgettable )
( cd usr/bin ; rm -rf psfstriptable )
( cd usr/bin ; ln -sf psfxtable psfstriptable )
( cd usr/bin ; rm -rf loadkeys )
( cd usr/bin ; ln -sf ../../bin/loadkeys loadkeys )
